==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/OAuthTemplatesFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class OAuthTemplatesFluentImpl<A extends io.fabric8.openshift.api.model.OAuthTemplatesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent<A>{
  public OAuthTemplatesFluentImpl() {
  }
  public OAuthTemplatesFluentImpl(io.fabric8.openshift.api.model.OAuthTemplates instance) {
    this.withError(instance.getError()); 
    this.withLogin(instance.getLogin()); 
    this.withProviderSelection(instance.getProviderSelection()); 
  }
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder error;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder login;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder providerSelection;
  
  /**
   * This method has been deprecated, please use method buildError instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getError() {
    return this.error!=null?this.error.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildError() {
    return this.error!=null?this.error.build():null;
  }
  public A withError(io.fabric8.openshift.api.model.SecretNameReference error) {
    _visitables.get("error").remove(this.error);
    if (error!=null){ this.error= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(error); _visitables.get("error").add(this.error);} return (A) this;
  }
  public java.lang.Boolean hasError() {
    return this.error != null;
  }
  public A withNewError(java.lang.String name) {
    return (A)withError(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> withNewError() {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ErrorNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> withNewErrorLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ErrorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> editError() {
    return withNewErrorLike(getError());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> editOrNewError() {
    return withNewErrorLike(getError() != null ? getError(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> editOrNewErrorLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewErrorLike(getError() != null ? getError(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildLogin instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getLogin() {
    return this.login!=null?this.login.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildLogin() {
    return this.login!=null?this.login.build():null;
  }
  public A withLogin(io.fabric8.openshift.api.model.SecretNameReference login) {
    _visitables.get("login").remove(this.login);
    if (login!=null){ this.login= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(login); _visitables.get("login").add(this.login);} return (A) this;
  }
  public java.lang.Boolean hasLogin() {
    return this.login != null;
  }
  public A withNewLogin(java.lang.String name) {
    return (A)withLogin(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> withNewLogin() {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.LoginNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> withNewLoginLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.LoginNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> editLogin() {
    return withNewLoginLike(getLogin());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> editOrNewLogin() {
    return withNewLoginLike(getLogin() != null ? getLogin(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> editOrNewLoginLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewLoginLike(getLogin() != null ? getLogin(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProviderSelection instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getProviderSelection() {
    return this.providerSelection!=null?this.providerSelection.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildProviderSelection() {
    return this.providerSelection!=null?this.providerSelection.build():null;
  }
  public A withProviderSelection(io.fabric8.openshift.api.model.SecretNameReference providerSelection) {
    _visitables.get("providerSelection").remove(this.providerSelection);
    if (providerSelection!=null){ this.providerSelection= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(providerSelection); _visitables.get("providerSelection").add(this.providerSelection);} return (A) this;
  }
  public java.lang.Boolean hasProviderSelection() {
    return this.providerSelection != null;
  }
  public A withNewProviderSelection(java.lang.String name) {
    return (A)withProviderSelection(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> withNewProviderSelection() {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> withNewProviderSelectionLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> editProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> editOrNewProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> editOrNewProviderSelectionLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OAuthTemplatesFluentImpl that = (OAuthTemplatesFluentImpl) o;
    if (error != null ? !error.equals(that.error) :that.error != null) return false;
    if (login != null ? !login.equals(that.login) :that.login != null) return false;
    if (providerSelection != null ? !providerSelection.equals(that.providerSelection) :that.providerSelection != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(error,  login,  providerSelection,  super.hashCode());
  }
  public class ErrorNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<N>> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ErrorNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ErrorNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withError(builder.build());
    }
    public N endError() {
      return and();
    }
    
  }
  public class LoginNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<N>> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LoginNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    LoginNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withLogin(builder.build());
    }
    public N endLogin() {
      return and();
    }
    
  }
  public class ProviderSelectionNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<N>> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ProviderSelectionNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ProviderSelectionNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withProviderSelection(builder.build());
    }
    public N endProviderSelection() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/OAuthTemplatesFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OAuthTemplatesFluentImpl<A extends io.fabric8.openshift.api.model.OAuthTemplatesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent<A>{
  public OAuthTemplatesFluentImpl() {
  }
  public OAuthTemplatesFluentImpl(io.fabric8.openshift.api.model.OAuthTemplates instance) {
    this.withError(instance.getError()); 
    this.withLogin(instance.getLogin()); 
    this.withProviderSelection(instance.getProviderSelection()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder error;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder login;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder providerSelection;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildError instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getError() {
    return this.error!=null?this.error.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildError() {
    return this.error!=null?this.error.build():null;
  }
  public A withError(io.fabric8.openshift.api.model.SecretNameReference error) {
    _visitables.get("error").remove(this.error);
    if (error!=null){ this.error= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(error); _visitables.get("error").add(this.error);} return (A) this;
  }
  public java.lang.Boolean hasError() {
    return this.error != null;
  }
  public A withNewError(java.lang.String name) {
    return (A)withError(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> withNewError() {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ErrorNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> withNewErrorLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ErrorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> editError() {
    return withNewErrorLike(getError());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> editOrNewError() {
    return withNewErrorLike(getError() != null ? getError(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<A> editOrNewErrorLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewErrorLike(getError() != null ? getError(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildLogin instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getLogin() {
    return this.login!=null?this.login.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildLogin() {
    return this.login!=null?this.login.build():null;
  }
  public A withLogin(io.fabric8.openshift.api.model.SecretNameReference login) {
    _visitables.get("login").remove(this.login);
    if (login!=null){ this.login= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(login); _visitables.get("login").add(this.login);} return (A) this;
  }
  public java.lang.Boolean hasLogin() {
    return this.login != null;
  }
  public A withNewLogin(java.lang.String name) {
    return (A)withLogin(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> withNewLogin() {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.LoginNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> withNewLoginLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.LoginNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> editLogin() {
    return withNewLoginLike(getLogin());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> editOrNewLogin() {
    return withNewLoginLike(getLogin() != null ? getLogin(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<A> editOrNewLoginLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewLoginLike(getLogin() != null ? getLogin(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProviderSelection instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getProviderSelection() {
    return this.providerSelection!=null?this.providerSelection.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildProviderSelection() {
    return this.providerSelection!=null?this.providerSelection.build():null;
  }
  public A withProviderSelection(io.fabric8.openshift.api.model.SecretNameReference providerSelection) {
    _visitables.get("providerSelection").remove(this.providerSelection);
    if (providerSelection!=null){ this.providerSelection= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(providerSelection); _visitables.get("providerSelection").add(this.providerSelection);} return (A) this;
  }
  public java.lang.Boolean hasProviderSelection() {
    return this.providerSelection != null;
  }
  public A withNewProviderSelection(java.lang.String name) {
    return (A)withProviderSelection(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> withNewProviderSelection() {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> withNewProviderSelectionLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.OAuthTemplatesFluentImpl.ProviderSelectionNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> editProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> editOrNewProviderSelection() {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<A> editOrNewProviderSelectionLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewProviderSelectionLike(getProviderSelection() != null ? getProviderSelection(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OAuthTemplatesFluentImpl that = (OAuthTemplatesFluentImpl) o;
    if (error != null ? !error.equals(that.error) :that.error != null) return false;
    if (login != null ? !login.equals(that.login) :that.login != null) return false;
    if (providerSelection != null ? !providerSelection.equals(that.providerSelection) :that.providerSelection != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(error,  login,  providerSelection,  additionalProperties,  super.hashCode());
  }
  public class ErrorNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<N>> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent.ErrorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ErrorNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ErrorNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withError(builder.build());
    }
    public N endError() {
      return and();
    }
    
  }
  public class LoginNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<N>> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent.LoginNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LoginNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    LoginNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withLogin(builder.build());
    }
    public N endLogin() {
      return and();
    }
    
  }
  public class ProviderSelectionNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<N>> implements io.fabric8.openshift.api.model.OAuthTemplatesFluent.ProviderSelectionNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ProviderSelectionNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ProviderSelectionNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluentImpl.this.withProviderSelection(builder.build());
    }
    public N endProviderSelection() {
      return and();
    }
    
  }
  
}
